# GitLab CI Ruby Example

Please refer to the [official documentation](https://docs.gitlab.com/ce/ci/yaml/README.html)
to view all configuration options available.

This project contains a simple Ruby library generated using `bundle gem`.
Tests are written using *RSpec*.

Let's break down the contents of `.gitlab-ci.yml`:

```yml
image: ruby:latest
```

The first line declares that the runner should use official 
[`maven`](https://hub.docker.com/_/ruby/) image.

```yml
stages:
  - test
```

The whole pipeline has only a single stage called `test`.

```yml
# Cache gems in between builds
cache:
  key: ${CI_COMMIT_REF_SLUG}
  paths:
    - vendor/ruby
```

Caching is an optimization, but isn't guaranteed to always work, so you need to be prepared to 
regenerate any cached files in each job that needs them. 
[See more](https://docs.gitlab.com/ee/ci/caching/#caching-ruby-dependencies)


```yml
before_script:
  - ruby -v                                   # Print out ruby version for debugging
  - gem install bundler  --no-ri --no-rdoc    # Bundler is not installed with the image
  - bundle install -j $(nproc) --path vendor  # Install dependencies into ./vendor/ruby
```

`before_script` is used to define the command that should be run before all jobs, 
including deploy jobs, but after the restoration of artifacts. 
This can be an array or a multi-line string.


```yml
test:
  stage: build
```

The second line seems superfluous, but in general the stages do not need
to be called `build` or `test` and there can be more than one.
The `stage: build` declaration merely informs the runner that this stage
is actually part of the build *phase*.


```yml
  tags:
    - shared-fi
```

`gitlab-ci.fi.muni.cz` will only run jobs that have tag `shared-fi`.


```yml
  script:
    - bundle exec rake spec 
```

Finally, the `script` section contains a list of commands that shall be
performed inside the repository once the runner starts.
These *should* be executed inside a single shell instance so that
`cd` and similar commands should work as expected, but unfortunately
this is not specified in the official documentation.




